Falcon JsonRpc Extensions
====================================

JsonRpc Extensions for Falcon framework


Installation
====================================

Via PyPI:

.. code:: bash

    pip install falcon_json_rpc

